==> ejc-settle-impl-3.0.0-20250122.023702-146-sources.jar: com/ejianc/business/settle/bean/SettlementCenterSystemDrwgrpEntity.java <==
package com.ejianc.business.settle.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算中心系统产值表
 * 
 * @author generator
 * 
 */
 @TableName("settlement_center_system_drwgrp")
public class SettlementCenterSystemDrwgrpEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="settlement_center_major")
    private String settlementCenterMajor; // 结算中心专业
    @TableField(value="settlement_center_major_name")
    private String settlementCenterMajorName; // 结算中心专业名称
    @TableField(value="statistical_output")
    private BigDecimal statisticalOutput; // 统计产值
    @TableField(value="desired_time")
    private Date desiredTime; // 期望完成时间
    @TableField(value="first_node_time")
    private Date firstNodeTime; // 数据生成的时间
    @TableField(value="second_node_time")
    private Date secondNodeTime; // 预算员接收时间
    @TableField(value="third_node_time")
    private Date thirdNodeTime; // 预算员提交时间
    @TableField(value="fourth_node_time")
    private Date fourthNodeTime; // 专业主管审核时间
    @TableField(value="fifth_node_time")
    private Date fifthNodeTime; // 结算中心项目负责人复审时间
    @TableField(value="sixth_node_time")
    private Date sixthNodeTime; // 项目合同主管复审时间
    @TableField(value="seventh_node_time")
    private Date seventhNodeTime; // 综合管理员复审归档时间
    @TableField(value="eighth_node_time")
    private Date eighthNodeTime; // 完成时间
    @TableField(value="third_node_user_id")
    private String thirdNodeUserId; // 预算员
    @TableField(value="fourth_node_user_id")
    private String fourthNodeUserId; // 专业主管
    @TableField(value="fifth_node_user_id")
    private Long fifthNodeUserId; // 结算中心项目负责人
    @TableField(value="sixth_node_user_id")
    private Long sixthNodeUserId; // 项目合同主管
    @TableField(value="seventh_node_user_id")
    private Long seventhNodeUserId; // 综合管理员
    @TableField(value="third_node_user_name")
    private String thirdNodeUserName; // 预算员
    @TableField(value="fourth_node_user_name")
    private String fourthNodeUserName; // 专业主管
    @TableField(value="fifth_node_user_name")
    private String fifthNodeUserName; // 结算中心项目负责人
    @TableField(value="sixth_node_user_name")
    private String sixthNodeUserName; // 项目合同主管
    @TableField(value="seventh_node_user_name")
    private String seventhNodeUserName; // 综合管理员
    @TableField(value="create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value="flow_state")
    private String flowState; // 流程状态
    @TableField(value="flow_state_name")
    private String flowStateName; // 流程状态名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="contract_id")
    private Long contractId; // 承包合同id
    @TableField(value="contract_code")
    private String contractCode; // 承包合同code
    @TableField(value="source_unitid")
    private String sourceUnitid; // 设计单位id
    @TableField(value="source_unitname")
    private String sourceUnitname; // 设计单位
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同金额
    @TableField(value="system_id")
    private Long systemId; // 系统id
    @TableField(value="system_name")
    private String systemName; // 系统名称

    @TableField(exist = false)
    @SubEntity(serviceName = "settlementCenterDcDrwgrpInfoService")
    private List<SettlementCenterDcDrwgrpInfoEntity> infoList = new ArrayList<>();

    public List<SettlementCenterDcDrwgrpInfoEntity> getInfoList() {
        return infoList;
    }

    public void setInfoList(List<SettlementCenterDcDrwgrpInfoEntity> infoList) {
        this.infoList = infoList;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getSettlementCenterMajor() {
        return settlementCenterMajor;
    }

    public void setSettlementCenterMajor(String settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }
    public String getSettlementCenterMajorName() {
        return settlementCenterMajorName;
    }

    public void setSettlementCenterMajorName(String settlementCenterMajorName) {
        this.settlementCenterMajorName = settlementCenterMajorName;
    }
    public BigDecimal getStatisticalOutput() {
        return statisticalOutput;
    }

    public void setStatisticalOutput(BigDecimal statisticalOutput) {
        this.statisticalOutput = statisticalOutput;
    }
    public Date getDesiredTime() {
        return desiredTime;
    }

    public void setDesiredTime(Date desiredTime) {
        this.desiredTime = desiredTime;
    }
    public Date getFirstNodeTime() {
        return firstNodeTime;
    }

    public void setFirstNodeTime(Date firstNodeTime) {
        this.firstNodeTime = firstNodeTime;
    }
    public Date getSecondNodeTime() {
        return secondNodeTime;
    }

    public void setSecondNodeTime(Date secondNodeTime) {
        this.secondNodeTime = secondNodeTime;
    }
    public Date getThirdNodeTime() {
        return thirdNodeTime;
    }

    public void setThirdNodeTime(Date thirdNodeTime) {
        this.thirdNodeTime = thirdNodeTime;
    }
    public Date getFourthNodeTime() {
        return fourthNodeTime;
    }

    public void setFourthNodeTime(Date fourthNodeTime) {
        this.fourthNodeTime = fourthNodeTime;
    }
    public Date getFifthNodeTime() {
        return fifthNodeTime;
    }

    public void setFifthNodeTime(Date fifthNodeTime) {
        this.fifthNodeTime = fifthNodeTime;
    }
    public Date getSixthNodeTime() {
        return sixthNodeTime;
    }

    public void setSixthNodeTime(Date sixthNodeTime) {
        this.sixthNodeTime = sixthNodeTime;
    }
    public Date getSeventhNodeTime() {
        return seventhNodeTime;
    }

    public void setSeventhNodeTime(Date seventhNodeTime) {
        this.seventhNodeTime = seventhNodeTime;
    }
    public Date getEighthNodeTime() {
        return eighthNodeTime;
    }

    public void setEighthNodeTime(Date eighthNodeTime) {
        this.eighthNodeTime = eighthNodeTime;
    }
    public String getThirdNodeUserId() {
        return thirdNodeUserId;
    }

    public void setThirdNodeUserId(String thirdNodeUserId) {
        this.thirdNodeUserId = thirdNodeUserId;
    }
    public String getFourthNodeUserId() {
        return fourthNodeUserId;
    }

    public void setFourthNodeUserId(String fourthNodeUserId) {
        this.fourthNodeUserId = fourthNodeUserId;
    }
    public Long getFifthNodeUserId() {
        return fifthNodeUserId;
    }

    public void setFifthNodeUserId(Long fifthNodeUserId) {
        this.fifthNodeUserId = fifthNodeUserId;
    }
    public Long getSixthNodeUserId() {
        return sixthNodeUserId;
    }

    public void setSixthNodeUserId(Long sixthNodeUserId) {
        this.sixthNodeUserId = sixthNodeUserId;
    }
    public Long getSeventhNodeUserId() {
        return seventhNodeUserId;
    }

    public void setSeventhNodeUserId(Long seventhNodeUserId) {
        this.seventhNodeUserId = seventhNodeUserId;
    }
    public String getThirdNodeUserName() {
        return thirdNodeUserName;
    }

    public void setThirdNodeUserName(String thirdNodeUserName) {
        this.thirdNodeUserName = thirdNodeUserName;
    }
    public String getFourthNodeUserName() {
        return fourthNodeUserName;
    }

    public void setFourthNodeUserName(String fourthNodeUserName) {
        this.fourthNodeUserName = fourthNodeUserName;
    }
    public String getFifthNodeUserName() {
        return fifthNodeUserName;
    }

    public void setFifthNodeUserName(String fifthNodeUserName) {
        this.fifthNodeUserName = fifthNodeUserName;
    }
    public String getSixthNodeUserName() {
        return sixthNodeUserName;
    }

    public void setSixthNodeUserName(String sixthNodeUserName) {
        this.sixthNodeUserName = sixthNodeUserName;
    }
    public String getSeventhNodeUserName() {
        return seventhNodeUserName;
    }

    public void setSeventhNodeUserName(String seventhNodeUserName) {
        this.seventhNodeUserName = seventhNodeUserName;
    }
    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }
    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getSourceUnitid() {
        return sourceUnitid;
    }

    public void setSourceUnitid(String sourceUnitid) {
        this.sourceUnitid = sourceUnitid;
    }
    public String getSourceUnitname() {
        return sourceUnitname;
    }

    public void setSourceUnitname(String sourceUnitname) {
        this.sourceUnitname = sourceUnitname;
    }

    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }
    public Long getSystemId() {
        return systemId;
    }

    public void setSystemId(Long systemId) {
        this.systemId = systemId;
    }
    public String getSystemName() {
        return systemName;
    }

    public void setSystemName(String systemName) {
        this.systemName = systemName;
    }
    
}

==> ejc-settle-impl-3.0.0-20250725.024836-165-sources.jar: com/ejianc/business/settle/bean/SettlementCenterSystemDrwgrpEntity.java <==
package com.ejianc.business.settle.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算中心系统产值表
 * 
 * @author generator
 * 
 */
 @TableName("settlement_center_system_drwgrp")
public class SettlementCenterSystemDrwgrpEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="settlement_center_major")
    private String settlementCenterMajor; // 结算中心专业
    @TableField(value="settlement_center_major_name")
    private String settlementCenterMajorName; // 结算中心专业名称
    @TableField(value="statistical_output")
    private BigDecimal statisticalOutput; // 统计产值
    @TableField(value="desired_time")
    private Date desiredTime; // 期望完成时间
    @TableField(value="first_node_time")
    private Date firstNodeTime; // 数据生成的时间
    @TableField(value="second_node_time")
    private Date secondNodeTime; // 预算员接收时间
    @TableField(value="third_node_time")
    private Date thirdNodeTime; // 预算员提交时间
    @TableField(value="fourth_node_time")
    private Date fourthNodeTime; // 专业主管审核时间
    @TableField(value="fifth_node_time")
    private Date fifthNodeTime; // 结算中心项目负责人复审时间
    @TableField(value="sixth_node_time")
    private Date sixthNodeTime; // 项目合同主管复审时间
    @TableField(value="seventh_node_time")
    private Date seventhNodeTime; // 综合管理员复审归档时间
    @TableField(value="eighth_node_time")
    private Date eighthNodeTime; // 完成时间
    @TableField(value="third_node_user_id")
    private String thirdNodeUserId; // 预算员
    @TableField(value="fourth_node_user_id")
    private String fourthNodeUserId; // 专业主管
    @TableField(value="fifth_node_user_id")
    private Long fifthNodeUserId; // 结算中心项目负责人
    @TableField(value="sixth_node_user_id")
    private Long sixthNodeUserId; // 项目合同主管
    @TableField(value="seventh_node_user_id")
    private Long seventhNodeUserId; // 综合管理员
    @TableField(value="third_node_user_name")
    private String thirdNodeUserName; // 预算员
    @TableField(value="fourth_node_user_name")
    private String fourthNodeUserName; // 专业主管
    @TableField(value="fifth_node_user_name")
    private String fifthNodeUserName; // 结算中心项目负责人
    @TableField(value="sixth_node_user_name")
    private String sixthNodeUserName; // 项目合同主管
    @TableField(value="seventh_node_user_name")
    private String seventhNodeUserName; // 综合管理员
    @TableField(value="create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value="flow_state")
    private String flowState; // 流程状态
    @TableField(value="flow_state_name")
    private String flowStateName; // 流程状态名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="contract_id")
    private String contractId; // 承包合同id
    @TableField(value="contract_code")
    private String contractCode; // 承包合同code
    @TableField(value="source_unitid")
    private String sourceUnitid; // 设计单位id
    @TableField(value="source_unitname")
    private String sourceUnitname; // 设计单位
    @TableField(value="contract_mny")
    private BigDecimal contractMny; // 合同金额
    @TableField(value="system_id")
    private Long systemId; // 系统id
    @TableField(value="system_name")
    private String systemName; // 系统名称
    @TableField(value="statistical_results")
    private String statisticalResults; // 统计成果文件名称
    @TableField(value="statistical_results_file")
    private String statisticalResultsFile; // 统计成果文件id

    public String getStatisticalResults() {
        return statisticalResults;
    }

    public void setStatisticalResults(String statisticalResults) {
        this.statisticalResults = statisticalResults;
    }

    public String getStatisticalResultsFile() {
        return statisticalResultsFile;
    }

    public void setStatisticalResultsFile(String statisticalResultsFile) {
        this.statisticalResultsFile = statisticalResultsFile;
    }

    @TableField(exist = false)
    @SubEntity(serviceName = "settlementCenterDcDrwgrpInfoService")
    private List<SettlementCenterDcDrwgrpInfoEntity> infoList = new ArrayList<>();

    @TableField(exist=false)
    @SubEntity(serviceName="settlementCenterSystemNumDetailService")
    private List<SettlementCenterSystemNumDetailEntity> settlementCenterSystemNumDetailList = new ArrayList<>(); // 结算中心系统工程量明细


    public List<SettlementCenterSystemNumDetailEntity> getSettlementCenterSystemNumDetailList() {
        return settlementCenterSystemNumDetailList;
    }

    public void setSettlementCenterSystemNumDetailList(List<SettlementCenterSystemNumDetailEntity> settlementCenterSystemNumDetailList) {
        this.settlementCenterSystemNumDetailList = settlementCenterSystemNumDetailList;
    }

    public List<SettlementCenterDcDrwgrpInfoEntity> getInfoList() {
        return infoList;
    }

    public void setInfoList(List<SettlementCenterDcDrwgrpInfoEntity> infoList) {
        this.infoList = infoList;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getSettlementCenterMajor() {
        return settlementCenterMajor;
    }

    public void setSettlementCenterMajor(String settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }
    public String getSettlementCenterMajorName() {
        return settlementCenterMajorName;
    }

    public void setSettlementCenterMajorName(String settlementCenterMajorName) {
        this.settlementCenterMajorName = settlementCenterMajorName;
    }
    public BigDecimal getStatisticalOutput() {
        return statisticalOutput;
    }

    public void setStatisticalOutput(BigDecimal statisticalOutput) {
        this.statisticalOutput = statisticalOutput;
    }
    public Date getDesiredTime() {
        return desiredTime;
    }

    public void setDesiredTime(Date desiredTime) {
        this.desiredTime = desiredTime;
    }
    public Date getFirstNodeTime() {
        return firstNodeTime;
    }

    public void setFirstNodeTime(Date firstNodeTime) {
        this.firstNodeTime = firstNodeTime;
    }
    public Date getSecondNodeTime() {
        return secondNodeTime;
    }

    public void setSecondNodeTime(Date secondNodeTime) {
        this.secondNodeTime = secondNodeTime;
    }
    public Date getThirdNodeTime() {
        return thirdNodeTime;
    }

    public void setThirdNodeTime(Date thirdNodeTime) {
        this.thirdNodeTime = thirdNodeTime;
    }
    public Date getFourthNodeTime() {
        return fourthNodeTime;
    }

    public void setFourthNodeTime(Date fourthNodeTime) {
        this.fourthNodeTime = fourthNodeTime;
    }
    public Date getFifthNodeTime() {
        return fifthNodeTime;
    }

    public void setFifthNodeTime(Date fifthNodeTime) {
        this.fifthNodeTime = fifthNodeTime;
    }
    public Date getSixthNodeTime() {
        return sixthNodeTime;
    }

    public void setSixthNodeTime(Date sixthNodeTime) {
        this.sixthNodeTime = sixthNodeTime;
    }
    public Date getSeventhNodeTime() {
        return seventhNodeTime;
    }

    public void setSeventhNodeTime(Date seventhNodeTime) {
        this.seventhNodeTime = seventhNodeTime;
    }
    public Date getEighthNodeTime() {
        return eighthNodeTime;
    }

    public void setEighthNodeTime(Date eighthNodeTime) {
        this.eighthNodeTime = eighthNodeTime;
    }
    public String getThirdNodeUserId() {
        return thirdNodeUserId;
    }

    public void setThirdNodeUserId(String thirdNodeUserId) {
        this.thirdNodeUserId = thirdNodeUserId;
    }
    public String getFourthNodeUserId() {
        return fourthNodeUserId;
    }

    public void setFourthNodeUserId(String fourthNodeUserId) {
        this.fourthNodeUserId = fourthNodeUserId;
    }
    public Long getFifthNodeUserId() {
        return fifthNodeUserId;
    }

    public void setFifthNodeUserId(Long fifthNodeUserId) {
        this.fifthNodeUserId = fifthNodeUserId;
    }
    public Long getSixthNodeUserId() {
        return sixthNodeUserId;
    }

    public void setSixthNodeUserId(Long sixthNodeUserId) {
        this.sixthNodeUserId = sixthNodeUserId;
    }
    public Long getSeventhNodeUserId() {
        return seventhNodeUserId;
    }

    public void setSeventhNodeUserId(Long seventhNodeUserId) {
        this.seventhNodeUserId = seventhNodeUserId;
    }
    public String getThirdNodeUserName() {
        return thirdNodeUserName;
    }

    public void setThirdNodeUserName(String thirdNodeUserName) {
        this.thirdNodeUserName = thirdNodeUserName;
    }
    public String getFourthNodeUserName() {
        return fourthNodeUserName;
    }

    public void setFourthNodeUserName(String fourthNodeUserName) {
        this.fourthNodeUserName = fourthNodeUserName;
    }
    public String getFifthNodeUserName() {
        return fifthNodeUserName;
    }

    public void setFifthNodeUserName(String fifthNodeUserName) {
        this.fifthNodeUserName = fifthNodeUserName;
    }
    public String getSixthNodeUserName() {
        return sixthNodeUserName;
    }

    public void setSixthNodeUserName(String sixthNodeUserName) {
        this.sixthNodeUserName = sixthNodeUserName;
    }
    public String getSeventhNodeUserName() {
        return seventhNodeUserName;
    }

    public void setSeventhNodeUserName(String seventhNodeUserName) {
        this.seventhNodeUserName = seventhNodeUserName;
    }
    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }
    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public String getSourceUnitid() {
        return sourceUnitid;
    }

    public void setSourceUnitid(String sourceUnitid) {
        this.sourceUnitid = sourceUnitid;
    }
    public String getSourceUnitname() {
        return sourceUnitname;
    }

    public void setSourceUnitname(String sourceUnitname) {
        this.sourceUnitname = sourceUnitname;
    }

    public BigDecimal getContractMny() {
        return contractMny;
    }

    public void setContractMny(BigDecimal contractMny) {
        this.contractMny = contractMny;
    }
    public Long getSystemId() {
        return systemId;
    }

    public void setSystemId(Long systemId) {
        this.systemId = systemId;
    }
    public String getSystemName() {
        return systemName;
    }

    public void setSystemName(String systemName) {
        this.systemName = systemName;
    }
    
}
